@@ -2,11 +2,13 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = '0.87'; # VERSION
+our $VERSION = '0.88'; # VERSION
 
 use Devel::Cover::DB;
+use Devel::Cover::Html_Common "launch";
 use Devel::Cover::Truth_Table;
 
+use Getopt::Long;
 use Template 2.00;
 use CGI;
 
@@ -14,6 +16,17 @@ my $Template;
 my %Filenames;
 my %File_exists;
 
+sub get_options
+{
+    my ($self, $opt) = @_;
+    $opt->{option}{outputfile} = "coverage.html";
+    die "Invalid command line options" unless
+        GetOptions($opt->{option},
+                   qw(
+                       outputfile=s
+                     ));
+}
+
 #-------------------------------------------------------------------------------
 # Subroutine : cvg_class()
 # Purpose    : Determine the CSS class for an element based on its amount of
@@ -101,7 +114,7 @@ sub print_summary {
         vals        => \%vals,
     };
 
-    my $html = "$options->{outputdir}/coverage.html";
+    my $html = "$options->{outputdir}/$options->{option}{outputfile}";
     $Template->process("summary", $vars, $html) or die $Template->error();
 
     print "HTML output sent to $html\n";
@@ -386,7 +399,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '0.87'; # VERSION
+our $VERSION = '0.88'; # VERSION
 
 use base "Template::Provider";
 
@@ -405,7 +418,7 @@ $Templates{html} = <<'EOT';
 <?xml version="1.0" encoding="utf-8"?>
 <!--
 This file was generated by Devel::Cover Version $VERSION
-Devel::Cover is copyright 2001-2011, Paul Johnson (pjcj\@cpan.org)
+Devel::Cover is copyright 2001-2012, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -704,7 +717,7 @@ s/^\s+//gm for values %Templates;
 
 =head1 VERSION
 
-version 0.87
+version 0.88
 Devel::Cover::Report::Html_subtle - Backend for HTML reporting of coverage
 statistics
 
@@ -730,7 +743,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
